.. -*- mode: rst -*-

sklearn-sfa - An implementation of Slow Feature Analysis compatible with scikit-learn
=====================================================================================

.. _scikit-learn: https://scikit-learn.org

.. _documentation: https://sklearn-sfa.readthedocs.io/en/latest/index.html

**sklearn-sfa** or **sksfa** is an implementation of Slow Feature Analysis for scikit-learn_.

It is meant as a standalone transformer for dimensionality reduction or as a building block
for more complex representation learning pipelines utilizing scikit-learn's extensive collection
of machine learning methods.

The package contains a solver for linear SFA and some auxiliary functions. The documentation_ 
provides an explanation of the algorithm, different use-cases, as well as pointers how to 
fully utilize SFA's potential, e.g., by employing non-linear basis functions or more sophisticated 
architectures.


